library(testthat)
library("MakefileR")

test_check("MakefileR")
